@@ -125,8 +125,7 @@ bool CollaborationManager::startGuestServer(const QString folder,const QString &
     }
     const QString binPath=m_conf->ce_toolPath;
     QString folderName=m_conf->ce_clientPath;
-    QDir dir(folderName);
-    dir.mkpath(".teamtype");
+
     if(!binPath.isEmpty()){
         // run binPath share folder
         collabServerProcess = new QProcess(this);
@@ -238,7 +237,10 @@ void CollaborationManager::sendChanges(QDocumentCursor cursor, const QString &ch
     }
     QDocumentLineHandle *dlh=cursor.line().handle();
     LatexDocument *doc=dynamic_cast<LatexDocument*>(dlh->document());
-    sendChanges(doc->getFileName(),cursor.lineNumber(),cursor.columnNumber(),cursor.anchorLineNumber(),cursor.anchorColumnNumber(),changes);
+    bool ok;
+    qint64 rev=doc->property("revision").toLongLong(&ok);
+    if(!ok) rev=0;
+    sendChanges(doc->getFileName(),cursor.lineNumber(),cursor.columnNumber(),cursor.anchorLineNumber(),cursor.anchorColumnNumber(),changes,rev);
 }
 /*!
  * \brief variant to send changes to connected editors
@@ -249,7 +251,7 @@ void CollaborationManager::sendChanges(QDocumentCursor cursor, const QString &ch
  * \param endCol
  * \param changes
  */
-void CollaborationManager::sendChanges(QString fileName, int startLine, int startCol, int endLine, int endCol, const QString &changes)
+void CollaborationManager::sendChanges(QString fileName, int startLine, int startCol, int endLine, int endCol, const QString &changes,qint64 rev)
 {
     if(!isClientRunning()){
         return;
@@ -259,7 +261,7 @@ void CollaborationManager::sendChanges(QString fileName, int startLine, int star
     jo["method"]="edit";
     QJsonObject jparams;
     jparams["uri"]="file://"+fileName;
-    jparams["revision"]=0; // for now
+    jparams["revision"]=rev; // for now
     QJsonObject jrange;
     QJsonObject jstart;
     jstart["line"]=startLine;
@@ -398,12 +400,23 @@ void CollaborationManager::readyCollabClientStandardOutput()
             if(method=="edit"){
                 QJsonObject ja=dd["params"].toObject();
                 QString uri=ja["uri"].toString();
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+                qint64 rev_received=ja["revision"].toInteger();
+#else
+                qint64 rev_received=ja["revision"].toInt();
+#endif
                 // find doc from uri
                 if(!uri.startsWith("file://")){
                     return;
                 }
                 QString fileName=uri.mid(7);
                 LatexDocument *doc=findDocumentFromName(fileName);
+                // update revision number
+                // apparently +1 per received changed request
+                bool ok;
+                qint64 rev=doc->property("revision").toLongLong(&ok);
+                if(!ok) rev=0;
+                doc->setProperty("revision",rev+1);
                 QJsonArray jdelta=ja["delta"].toArray();
                 if(jdelta.size()>0){
                     QJsonObject jelem=jdelta[0].toObject();
@@ -456,7 +469,7 @@ void CollaborationManager::readyCollabServerStandardOutput()
         for(QString line : lines){
             line=line.trimmed();
             if(line.startsWith("teamtype join")){
-                m_code=line.mid(15);
+                m_code=line.mid(14);
                 emit hostServerSuccessfullyStarted();
             }
         }
@@ -465,6 +478,10 @@ void CollaborationManager::readyCollabServerStandardOutput()
         // send y
         collabServerProcess->write("y\n");
     }
+    if(buffer.contains("Do you want to enable live collaboration here?") && buffer.contains("(y/N):")){
+        // send y
+        collabServerProcess->write("y\n");
+    }
     qDebug() << "Collab Server Output:" << buffer;
 }
 /*!
@@ -500,6 +517,8 @@ void CollaborationManager::openFileInClient(const QString &fileName)
 {
     LatexDocument *doc=findDocumentFromName(fileName);
     if(!doc) return; // document not open
+    // reset revision
+    doc->setProperty("revision",0);
     // open file, send json
     QJsonObject jo;
     jo["jsonrpc"]="2.0";
